
Test doc
========

This document is parsed with bs4 to ensure that the rendered HTML matches the
expected output:

.. terminal::
    :copy:
    :scroll:
    :user: author
    :host: canonical
    :dir: ~/path

    input

    output


The following documents include more examples for manual review:

.. toctree::
    :maxdepth: 1

    rst-examples
    myst-examples
